#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-LoZMgvaT4VJ9bVvAfgTsw7
key:                  stack-2.9.3.1-LoZMgvaT4VJ9bVvAfgTsw7
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  9d6317a3408fdca80b55427b5d29a4b9
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-LoZMgvaT4VJ9bVvAfgTsw7
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-5nZVpYMolxlDp5iPgkZNkW array-0.5.6.0
    async-2.2.6-L49doqolqOiLsPy3OvdI1h
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP base-4.18.2.1
    base64-bytestring-1.2.1.0-7JruMLJLgBF2cqlGBjJEVX
    bytestring-0.11.5.3 casa-client-0.0.3-38GjjK3xTQ6496UsovNDLk
    casa-types-0.0.3-76b4csnCG0KExqPn2oBlk8
    colour-2.3.7-31ZT5BUmuB5DnL5v9CZhqv
    conduit-1.3.6.1-534uwm1BQ035a3x29nwuhR
    conduit-extra-1.3.8-1DWgHn4WIu2hT6xloHtnR containers-0.6.7
    crypton-1.0.4-GFZcLsOAlSN77AqvXDOpN4
    crypton-conduit-0.2.3-4AowXEKvjEJ4EY3ujQjrjy deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-EBdVSHGIn1MFifI9eiYLtn
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-JuXXdKolhfh9Pbe1V6jEso filepath-1.4.300.1
    fsnotify-0.4.4.0-6bPTrqD3dyFCbpeBwRBUHS
    generic-deriving-1.14.7-5EVA7USioDvAPoGbgrXr77
    hackage-security-0.6.3.2-CXFcLT69GHj4CrhpZQFTVt
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy
    hi-file-parser-0.1.8.0-5dnuzaOk1cGCwNgRkE2EVI
    hpack-0.38.0-7wmKCzrQocH4fgzex9Cczn hpc-0.6.2.0
    http-client-0.7.19-BV4AT2QZinhAZt9DyDMIrY
    http-client-tls-0.3.6.4-4PkwIHdSyLZEv9DDXogskJ
    http-conduit-2.3.9.1-JcUtgfOUbxf5vdq2wc5MPb
    http-download-0.2.1.0-7owsdyfgSsaGtfO79FjjTm
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-8KM6OBBCRc423NfutM9AmY mtl-2.3.1
    mustache-2.4.3.1-2ZqeNfbOmfU1XSWG8DGwcx
    neat-interpolation-0.5.1.4-4BrXKUgVQFw587XQUVzowq
    network-uri-2.6.4.2-DXIr6FO81fkKKSx83uC4Cz
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-7oEyKoVs7Vv7h3tuBTvFI7
    pantry-0.8.3-KmfxnEdTvaZz0RLGzFNSe
    path-0.9.6-2oUBJmvWCHrEflkfSbQjk1
    path-io-1.8.2-F2cen5JfEqQHEPewLISEYj
    persistent-2.14.5.2-E7tj1bN59VcDNU1kXNXcaK
    persistent-sqlite-2.13.2.0-46zeWb3YevR7mGoTLlAD9q pretty-1.1.3.6
    primitive-0.9.1.0-BFOZgwmJzy9HvkVKyhwLqr process-1.6.19.0
    project-template-0.2.1.0-7LdazY23C6nJqLlvWojF8z
    random-1.2.1.3-5FoUrrA3875KkJXWnCWBBA
    retry-0.9.3.1-FiXUOeJkTzZLKJEWVHgT6
    rio-0.1.24.0-FuD4aNlY6bHCSSQPUrx70a
    rio-prettyprint-0.1.8.0-ADtulK3ctOn29s8fZM5DW
    split-0.2.5-Bi3HfS9SciuGUuXE3PHa4h stm-2.5.1.0
    streaming-commons-0.2.3.1-JJ0HqrqWmbwFwDZTTxD1qw
    tar-0.5.1.1-9FAZ9ENRNcHHkCEDkycF5g template-haskell-2.20.0.0
    temporary-1.3-A3KjuMYmCbV2j39Y1k6FK6 text-2.0.2
    text-metrics-0.3.3-IqvD2hZSF7mAfBuwL21xpx
    th-reify-many-0.1.10-IY79bfHYL49Dmr4COP0Ec1 time-1.12.2
    tls-2.0.6-KHZe3dGSZTn2FTi1anEZiy transformers-0.6.1.0
    typed-process-0.2.13.0-3njdao0UBftC0M0fDGFJH2
    unicode-transforms-0.4.0.1-JSw3xw8e8HDBt5r6EVET1f unix-2.8.4.0
    unix-compat-0.7.4.1-LoSzSzurNX35X2SSxikovd
    unliftio-0.2.25.1-Jl71xZxtWw8GvgwO5TEzPz
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4
    yaml-0.11.11.2-FLCCKo0n0nJK5o0PhDW0y0
    zip-archive-0.4.3.2-6eqUWnN2688HRihZDcXAjj
    zlib-0.7.0.0-686OwP9DUwbK0zgIqxKgoM

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

